import stan
import matplotlib.pyplot as plt
import seaborn as sb
import arviz as az
import numpy as np

LData =  [ 44, 44, 56, 59, 44, 44, 63, 60, 34, 58,
           55, 50, 32, 61, 47, 25, 38, 47, 30, 42]
Data = np.array(LData)
mu_p = Data.mean()
sgm_p = np.std(Data)

OneVar_dat = { 'J': len(LData), 'y': LData, 'mu_p': mu_p, 'sgm_p': sgm_p}
with open('OneVar.stan', 'r') as fstan:
    sm = stan.build(fstan.read(), data = OneVar_dat)
fit = sm.sample()

i_data = az.from_pystan(posterior = fit, posterior_model = sm)
smry = az.summary(i_data)
print('Summary =\n',smry)

az.plot_trace(i_data, var_names = ['mu', 'sigma'])
plt.show()

d_fm = fit.to_frame()
q1_mu, q2_mu, q3_mu = np.percentile(d_fm['mu'], [25, 50, 75])
plt.title('Posterior Distribution of $\mu$' +
          f'\nQ1 = {q1_mu:.2f}, Med.= {q2_mu:.2f}, Q3 = {q3_mu:.2f}')
sb.kdeplot(d_fm['mu'])
plt.xlabel('$\mu$', fontsize = 16)
plt.show()

q1_sgm, q2_sgm, q3_sgm = np.percentile(d_fm['sigma'], [25, 50, 75])
plt.title('Posterior Distribution of $\sigma$' +
          f'\nQ1 = {q1_sgm:.2f}, Med.= {q2_sgm:.2f}, Q3 = {q3_sgm:.2f}')
sb.kdeplot(d_fm['sigma'])
plt.xlabel('$\sigma$', fontsize = 16)
plt.show()
